""" Author: R. Le Gac 

"""

from gluon.storage import Storage
from modifier import Modifier


MODIFIER_FIELDS = 'modifier_fields'


class FieldsModifier(Modifier):
    """Helper tool to customise the field widget of a table.
    
    """
    
    def __init__(self, tablename):
        """Initialize the modifier persistent data.
        
        """
        Modifier.__init__(self, MODIFIER_FIELDS, tablename)

        if 'extjs_fields' not in self.data:
            self.data.extjs_fields = {}
        
            self.data.composite_fields = Storage()
            self.data.composite_fields.main = []
            self.data.composite_fields.others = []


    def append_plugins(self, *plugins):
        """Overwrite the method of the base class since it make
        no sense in for this modifier.
        
        """


    def configure(self, **extjs):
        """Overwrite the method of the base class since it make
        no sense in for this modifier.
        
        """
        
        
    def configure_field(self, field, **kwargs):
        """Update the configuration options of the field widget:
        Ext.form.Field, Ext.form.DateField, Ext.form.TextField....
        
        Existing value of the configuration options are replace by those 
        defined by the keyword arguments.
        
        """
        self.data.extjs_fields[field] = kwargs


    def merge_fields(self, *fields, **kwargs):
        """Merge fields in a composite field corresponding to 
        an Ext.form.CompositeField widget. 
        
        Each field is identified by its database field name.
        
        The keyword arguments contains the configuration options of
        the Ext.form.CompositeField widget.
                
        """

        # define the main field as the first field in the list
        main_field = fields[0]
        other_fields = fields[1:]
          
        # In order to simplify the processing keep a list of
        # the main field and a list of the other fields.
        self.data.composite_fields.main.append(main_field)
        self.data.composite_fields.others.extend(other_fields)
        
        di = Storage(fields=fields, extjs=kwargs)
        self.data.composite_fields[main_field] = di
