""" Author: R. Le Gac

"""

from gluon.storage import Storage
from gluon.tools import PluginManager
from helper import get_store_id
from modifier import Modifier


MODIFIER_STORES = 'modifier_stores'


class AddStore(object):
    """Helper tool to add the configuration of a store.
    The configuration of all store are kept in a dedicated dictionary
    which is given to the client via the action dbui_conf.
    
    This tool is suited to defined static store (Ext.data.ArrayStore) used
    for example in selectors. It should not be used to define store 
    associated to the database tables. The latter are configured using the 
    converter to_jsonstore. 
    
    However, this approach is generic and any store can be added to the 
    configuration dictionary.
    
    """ 
    
    def __init__(self, name, **kwargs):
        """ Create the configuration of a Store.
        
        the ExtJS configuration parameters of the store are defined
        by the keyword arguments kwargs.
        
        For an Ext.data.ArrayStore the properties fields and data
        have to be defined. For more details see the ExtJS documentation.
        
        The key associated to this store in the configuration dictionary
        is the storeId. It derived from the name in the 
        following way: nameStore.
        
        """
        static_stores = PluginManager('dbui').dbui.static_stores
    
        storeId = get_store_id(name)
        kwargs['storeId'] = storeId
        static_stores[storeId] = kwargs

    
class StoreModifier(Modifier):
    """Helper tool to customize the store associated to a table.
    
    """
    
    def __init__(self, tablename):
        """Initialize the modifier persistent data.
        
        """
        Modifier.__init__(self, MODIFIER_STORES, tablename)

        if 'orderby' not in self.data:
            self.data.orderby = []


    def orderby(self, *fields):
        """Order the store according to the list of database fields.
        
        """
        self.data.orderby.extend(fields)
