/**
 *  A border layout with a panel and a selector.
 *
 *  The selector is a collapsible panel appearing on the
 *  left/right/top/bottom side of the central panel.
 *  The selector contains a set of Fields usually organized in field sets.
 *  and two buttons Go and Reset.
 *
 *  The configuration parameter selectorRegion defined the position
 *  of the selector with respect to the central panel. Value are those
 *  of the border layout: east, west, south and north.
 *  By default the selector is on the east side (right).
 *
 *  The size of the selector is determined by selectorHeight and selectorWidth.
 *  The former works when the selectorRegion is north and south while
 *  the latter is for region west and east.
 *
 *  The logic between the panel, the selector and the buttons
 *  is defined in inherited class.
 *
 *  The type of this component is xpanelwithselector.
 *
 *  @extend: Ext.Panel
 *
 */
Ext.namespace('App');

App.BasePanelWithSelector = Ext.extend(Ext.Panel, {

    /**
     * @param {Object} panel and selector configurations
     */
    panelCfg: null,
    selectorCfg: null,

    /**
     * configuration options for the border layout
     */
    panelBorder: false,
    selectorCollapsible: true,
    selectorFrame: true,
    selectorHeight: 300,
    selectorRegion: 'east',
    selectorSplit: true,
    selectorWidth: 300,

    /**
     * Private attribute for internationalization
     */
    textGo: 'Go',
    textReset: 'Reset',

    /**
     * constructor
     * @param {Object} config
     */
    constructor: function(config) {

        var cfg,
            itemPanel,
            itemSelector,
            panel,
            selector;

        Ext.apply(this, config);

        // configure the panel item
        panel = Ext.ComponentMgr.create(this.panelCfg);
        itemPanel = {
            border: this.panelBorder,
            layout: 'fit',
            itemId: 'mainPanel',
            items: [panel],
            region: 'center'
        };

        // configure the selector item
        selector = Ext.ComponentMgr.create(this.selectorCfg);
        itemSelector = {
            buttons: [{
                ref: '../../goButton',
                text: this.textGo
            }, {
                ref: '../../resetButton',
                text: this.textReset
            }],
            collapsible: this.selectorCollapsible,
            defaults: {anchor: '99%'},
            frame: this.selectorFrame,
            height: this.selectorHeight,
            layout: 'form',
            itemId: 'selectorPanel',
            items: [selector],
            region: this.selectorRegion,
            split: this.selectorSplit,
            width: this.selectorWidth
        };

        // configure the border layout
        cfg = {
            layout: 'border',
            items: [itemPanel, itemSelector]
        };

        Ext.apply(this, cfg);

        // instanciate the panel
        App.BasePanelWithSelector.superclass.constructor.call(this);
    }
});

Ext.reg('xpanelwithselector', App.BasePanelWithSelector);
