/**
 * The Grid class is Ext.grid.GridPanel with a Ext.PagingToolbar
 * Many functionality can be added through grid plugins like
 * App.grid.RowEditor, ....
 *
 * The type of this component is xgrid.
 *
 * @extends Ext.gridPanel
 * @version
 *
 */

Ext.namespace('App.grid');

App.grid.Grid = Ext.extend(Ext.grid.GridPanel, {

    /**
     * @cfg nRows integer
     * Default number of rows display in the grid.
     * This parameter is only use when running with a paging plugin.
     */
    nRows: 10,

    /**
     * @event resetgrid
     * Can be used to reset underlying plugin when the reset
     * method is triggered
     */
    /**
     * private attributes used by plugins
     */
    rowEditor: null,

    /**
     * Constructor
     *
     * NOTE:
     * Required in ExtJS 3.4 convert rownumberer xtype
     * into an Ext.grid.RowNumberer. Not needed in ExtJS 4
     *
     */
    constructor: function (config) {

        var first_column = config.columns[0];

        if ('xtype' in first_column && first_column.xtype === 'rownumberer') {
            config.columns[0] = new Ext.grid.RowNumberer();
        }

        Ext.apply(this, config);
        App.grid.Grid.superclass.constructor.call(this);
    },
    /**
     * private method requests by the component model of ExtJS
     */
    initComponent: function () {

        // link the grid to the data store
        this.store = App.getStore(this.store);

        // empty toolBar requires by the plugins
        this.bbar = new Ext.Toolbar();

        // initialise the underlying class. DON'T MOVE
        App.grid.Grid.superclass.initComponent.call(this);

        // load the store if not yet done
        // if the grid paging is used load only the first 10 rows
        if (!this.store.getTotalCount()) {
            if (App.isPlugin(this, 'pGridPaging')) {
                this.store.load({params: {start: 0, limit: this.nRows}});
            } else {
                this.store.load();
            }
        }
    },
    /**
     * reset the grid
     * The store is load with fresh data and the event 'resetgrid' is emitted.
     * Paging and slider plugin might be reset using the 'resetgrid' event.
     * GridFilter object can be also reset using the same mechanism.
     *
     * The scope is the grid
     *
     */
    reset: function () {

        var action;

        // private function to emit the resetgrid event
        function fireReset() {
            this.fireEvent('resetgrid');
        }

        // parameters defining the store load action
        action = {callback: fireReset, scope: this};
        if (this.getBottomToolbar() instanceof Ext.PagingToolbar) {
            action.params = {start: 0, limit: this.nRows};
        }

        // restore initial where condition of the store
        // in order to remove remote filter condition
        this.store.restoreWhere();

        // reload the store and fire the resetgrid event
        this.store.load(action);
    }
});

Ext.reg('xgrid', App.grid.Grid);
