/**
 * Plugin to render mathematics formula embedded in HTML content.
 * The processing is performed by MathJax.
 * The MathJax library is loaded by the framework
 *
 * @version
 *
 */

Ext.namespace('App.panel');

App.panel.MathJax = Ext.extend(Object, {

    init: function (panel) {

        // register an handler which is activated only once
        // when the panel is rendered for the first time
        panel.on('render', this.onPanelRender, this, {single: true});
    },

    /**
     * Handler to activates the MathJax processing
     * when the html content of the panel is loaded.
     *
     * @param {Ext.Panel} panel
     */
    onPanelRender: function (panel) {
        var updater = panel.body.getUpdater();
        updater.on('update', this.onProcess);
    },

    /**
     * Handler to run the mathJax processing
     * @param {Ext.Element} el
     * @param {Object} o the response object
     */
    onProcess: function (e, o) {
        MathJax.Hub.PreProcess();
        MathJax.Hub.Process();
    }
});

Ext.preg('pPanelMathJax', App.panel.MathJax);
