/**
 * Plugin to add login capabilities to the viewport
 * The ptype of this component is pViewportLogin.
 *
 * The URL:
 *      login      → /application/admin
 *      Change pwd → /application/default/user/change_password
 *      Logout     → /application/default/user/logout
 * @extends Object
 * @version
 *
 */

Ext.namespace('App');

App.ViewportLogin = Ext.extend(Object, {

    /**
     * Private attribute identifying the type of plugin
     */
    ptype: 'pViewportLogin',

    /**
     * Private attributes for internationalization
     */
    textChangePwd: "Change password...",
    textLogin: "Login...",
    textLogout: "Logout",
    textSignIn: "Sign in",


    /**
     * Plugin initialization
     * @param {Object} viewport
     */
    init: function(viewport) {

        var inhibit_login = false,
            inhibit_logout = true,
            menu,
            tbar = viewport.getComponent('topBar');

        if (viewport.logged) {
            inhibit_login = true;
            inhibit_logout = false;
        }

        menu = new Ext.Toolbar.SplitButton({
            text: this.textSignIn,
            menu: {
                items: [{
                    disabled: inhibit_login,
                    href: "/" + App.name + "/admin",
                    text: this.textLogin

                }, '-', {
                    disabled: inhibit_logout,
                    href: "/" + App.name + "/default/user/change_password",
                    text: this.textChangePwd

                }, '-', {
                    disabled: inhibit_logout,
                    href: "/" + App.name + "/default/user/logout",
                    text: this.textLogout

                }]
            }
        });
        tbar.add('->', menu);
        tbar.setVisible(true);
    }
});

Ext.preg('pViewportLogin', App.ViewportLogin);
